==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/collection/request/UserExperienceAnalyticsDevicePerformanceCollectionRequest.java <==
package odata.msgraph.client.beta.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.guavamini.Preconditions;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.Map;

import odata.msgraph.client.beta.entity.UserExperienceAnalyticsDevicePerformance;
import odata.msgraph.client.beta.entity.request.UserExperienceAnalyticsDevicePerformanceRequest;
import odata.msgraph.client.beta.enums.UserExperienceAnalyticsSummarizedBy;
import odata.msgraph.client.beta.schema.SchemaInfo;

public class UserExperienceAnalyticsDevicePerformanceCollectionRequest extends CollectionPageEntityRequest<UserExperienceAnalyticsDevicePerformance, UserExperienceAnalyticsDevicePerformanceRequest>{

    protected ContextPath contextPath;

    public UserExperienceAnalyticsDevicePerformanceCollectionRequest(ContextPath contextPath) {
        super(contextPath, UserExperienceAnalyticsDevicePerformance.class, cp -> new UserExperienceAnalyticsDevicePerformanceRequest(cp), SchemaInfo.INSTANCE);
        this.contextPath = contextPath;
    }

    @Function(name = "summarizeDevicePerformanceDevices")
    @JsonIgnore
    public CollectionPageNonEntityRequest<UserExperienceAnalyticsDevicePerformance> summarizeDevicePerformanceDevices(UserExperienceAnalyticsSummarizedBy summarizeBy) {
        Preconditions.checkNotNull(summarizeBy, "summarizeBy cannot be null");
        Map<String, TypedObject> _parameters = ParameterMap
            .put("summarizeBy", "microsoft.graph.userExperienceAnalyticsSummarizedBy", summarizeBy)
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.summarizeDevicePerformanceDevices"), UserExperienceAnalyticsDevicePerformance.class, _parameters, odata.msgraph.client.beta.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/collection/request/UserExperienceAnalyticsDevicePerformanceCollectionRequest.java <==
package odata.msgraph.client.beta.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.guavamini.Preconditions;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.entity.UserExperienceAnalyticsDevicePerformance;
import odata.msgraph.client.beta.entity.request.UserExperienceAnalyticsDevicePerformanceRequest;
import odata.msgraph.client.beta.enums.UserExperienceAnalyticsSummarizedBy;

public class UserExperienceAnalyticsDevicePerformanceCollectionRequest extends CollectionPageEntityRequest<UserExperienceAnalyticsDevicePerformance, UserExperienceAnalyticsDevicePerformanceRequest>{

    protected ContextPath contextPath;

    public UserExperienceAnalyticsDevicePerformanceCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, UserExperienceAnalyticsDevicePerformance.class, cp -> new UserExperienceAnalyticsDevicePerformanceRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    @Function(name = "summarizeDevicePerformanceDevices")
    @JsonIgnore
    public CollectionPageNonEntityRequest<UserExperienceAnalyticsDevicePerformance> summarizeDevicePerformanceDevices(UserExperienceAnalyticsSummarizedBy summarizeBy) {
        Preconditions.checkNotNull(summarizeBy, "summarizeBy cannot be null");
        Map<String, TypedObject> _parameters = ParameterMap
            .put("summarizeBy", "microsoft.graph.userExperienceAnalyticsSummarizedBy", summarizeBy)
            .build();
        return CollectionPageNonEntityRequest.forFunction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.summarizeDevicePerformanceDevices"), UserExperienceAnalyticsDevicePerformance.class, _parameters);
    }

}
